find_salt

Function find_salt 

pub(crate) fn find_salt(
    master: Address,
    salt: Option<B256>,
    threads: Option<usize>,
    seed: Option<B256>,
    no_random: bool,
    quiet: bool,
    label: &str,
) -> Result<(Output, Option<Duration>)>
Validates master and returns the registration to submit: salt after checking its proof of work, or a freshly mined salt together with the time it took to find it.